Tutorials
=========

The best way to learn about GluonTS is to dive right in by following our tutorials. You can download each tutorial as a Jupyter notebook by clicking the *download* link at the top of each tutorial page.

Forecasting
-----------

.. container:: cards

   .. card::
      :title: Quick Start Tutorial
      :link: forecasting/quick_start_tutorial.html

      A quick start guide on how to use the essential features of GluonTS: loading data, training an existing model, evaluating its accuracy.

   .. card::
      :title: Extended Forecasting Tutorial
      :link: forecasting/extended_tutorial.html

      An extended tutorial, covering all features of GluonTS more extensively, and explaining how to write your own model using MXNet Gluon.

   .. card::
      :title: Write your own GluonTS model with PyTorch
      :link: forecasting/howto_pytorch_lightning.html

      An example of how one can use PyTorch to write a GluonTS forecasting model, and train it with PyTorch Lightning.

Data manipulation
-----------------

.. container:: cards

   .. card::
      :title: Synthetic Data Generation
      :link: data_manipulation/synthetic_data_generation.html

      A tutorial on how to use the synthetic data generation toolbox in GluonTS.

.. toctree::
   :hidden:
   :maxdepth: 1

   forecasting/quick_start_tutorial.ipynb
   forecasting/extended_tutorial.ipynb
   forecasting/howto_pytorch_lightning.ipynb
   data_manipulation/synthetic_data_generation.ipynb
